Reference Manual
================

This reference manual details modules, functions, and variables included in
Manim DSA, describing what they are and what they do.  For learning how to use
Manim DSA, see :doc:`guides`.  For a list of changes since the last release, see
the :doc:`changelog`.

Module Index
------------

.. toctree::
   :maxdepth: 3

   reference/data_structures
   reference/utils